:
#	@(#) prep.sup.os 1.2 88/02/16 
#
#	Copyright (C) The Santa Cruz Operation, 1987.
#	This Module contains Proprietary Information of
#	The Santa Cruz Operation, Microsoft Corporation
#	and AT&T, and should be treated as Confidential.
#
PATH=/bin:/usr/bin:/etc
prd=sup.os

# Return code definitions 
: ${OK=0} ${FAIL=1} ${STOP=10} ${HALT=11}

# set up default values
quit=quit				# q option printed after prompt
tmp=/tmp/script$$			# temporary file name 
retn="\007\nand press <RETURN> "	# commonly used in prompts

# Functions definitions

# Remove temp files and exit with the status passed as argument
cleanup() {
	trap '' 1 2 3 15
	rm -f $tmp*
	exit $1
}

# Print an error message
error() {
	echo "\nError: $*" >&2
	return 1
}

trap 'cleanup 1' 1 2 3 15


# Prompt with mesg, return non-zero on q. Also allows setting -x and +x,
# shell escapes and the passing of default values
prompt() {
	mesg=$1
	while	echo "\n${mesg}or enter q to $quit: \c" >&2
	do	read cmd
		case $cmd in
		+x|-x)	set $cmd					;;
		Q|q)	return 1					;;
		!*)	eval `expr "$cmd" : "!\(.*\)"`			;;
		"")	# If there is an second argument use it
			# as the default else loop until 'cmd' is set
			[ "$2" ] && { 
				cmd=$2
				return 0
			}
			: continue
			;;
		*)	return 0					;;
		esac
	done
}

# Prompt for yes or no answer - returns non-zero for no
getyn() {
	while	echo "\n$* (y/n) \c" >&2
	do	read yn rest
		case $yn in
		[yY])	return 0 				;;
		[nN])	return 1				;;
		*)	echo "\nPlease answer y or n" >&2	;;
		esac
	done
}

if	[ ! `who | wc -w` -eq 0 ]
then	echo "\nThe Operating System supplement should be installed in"
	echo "single user ("System Maintenance") mode, otherwise unpredictable"
	echo "failures may occur during installation."
	getyn "Are you absolutely sure you wish to install in multi-user mode?"\
		|| exit $STOP
fi

uname -r | grep '2\.[2-9]\.[1-9]' 2>&1 >/dev/null && exit $OK

echo "Your system does not appear to be running XENIX System V release 2.2.1"
echo "or greater.  Please note that this International XENIX Supplement is not"
echo "supported on XENIX systems before release 2.2.1, and that unpredictable"
echo "behaviour may occur on such systems."

getyn "Do you wish to continue with installation?" && exit $OK

exit $STOP
